@@ -1,4 +1,6 @@
 # -*- encoding: utf-8 -*-
+import sys
+sys.path.append("..")
 import pandas as pd
 from sklearn.linear_model import LogisticRegression
 from sklearn.model_selection import train_test_split
@@ -12,10 +14,9 @@ from grid import getClassificationGridDict
 from sklearn.preprocessing import MinMaxScaler
 from sklearn.preprocessing import StandardScaler
 from base import basePredict
-from classification import _base
+import classification._base
 import logging
 import time
-import scorers
 
 
 
@@ -106,7 +107,7 @@ class autoClassify(basePredict):
         if self.scaler:
             X_scaled = self._encodeData(X_scaled, self._encode_dict[self.encoder])
 
-        ## check if binar classification
+        ## check if binary classification
 
         if len(y.value_counts()) > 2:
             logging.warning('More then 2 target classes detected , scoring '
